==> gwasrapidd_0.99.12.tar.gz: gwasrapidd/tests/testthat/mocks/gc/s/GCST0/associations.R <==
structure(list(url = "gc/s/GCST0/associations", status_code = 404L, 
    headers = structure(list(server = "Apache-Coyote/1.1", `cache-control` = "no-cache, no-store, max-age=0, must-revalidate", 
        `strict-transport-security` = "max-age=0", date = "Thu, 25 Nov 2021 22:45:03 GMT", 
        `x-application-context` = "application", expires = "0", 
        `x-xss-protection` = "1; mode=block", pragma = "no-cache", 
        `transfer-encoding` = "chunked", `x-content-type-options` = "nosniff", 
        `x-frame-options` = "DENY"), class = c("insensitive", 
    "list")), all_headers = list(list(status = 404L, version = "HTTP/1.1", 
        headers = structure(list(server = "Apache-Coyote/1.1", 
            `cache-control` = "no-cache, no-store, max-age=0, must-revalidate", 
            `strict-transport-security` = "max-age=0", date = "Thu, 25 Nov 2021 22:45:03 GMT", 
            `x-application-context` = "application", expires = "0", 
            `x-xss-protection` = "1; mode=block", pragma = "no-cache", 
            `transfer-encoding` = "chunked", `x-content-type-options` = "nosniff", 
            `x-frame-options` = "DENY"), class = c("insensitive", 
        "list")))), cookies = structure(list(domain = logical(0), 
        flag = logical(0), path = logical(0), secure = logical(0), 
        expiration = structure(numeric(0), class = c("POSIXct", 
        "POSIXt")), name = logical(0), value = logical(0)), row.names = integer(0), class = "data.frame"), 
    content = raw(0), date = structure(1637880303, class = c("POSIXct", 
    "POSIXt"), tzone = "GMT"), times = c(redirect = 0, namelookup = 0.023132, 
    connect = 0.072856, pretransfer = 0.137106, starttransfer = 0.194565, 
    total = 0.194846)), class = "response")

==> gwasrapidd_0.99.18.tar.gz: gwasrapidd/tests/testthat/mocks/gc/s/GCST0/associations.R <==
structure(list(url = "gc/s/GCST0/associations", status_code = 404L, 
    headers = structure(list(server = "Apache-Coyote/1.1", `cache-control` = "no-cache, no-store, max-age=0, must-revalidate", 
        `strict-transport-security` = "max-age=0", date = "Sun, 04 Jun 2023 13:59:40 GMT", 
        `x-application-context` = "application", expires = "0", 
        `x-xss-protection` = "1; mode=block", pragma = "no-cache", 
        `transfer-encoding` = "chunked", `x-content-type-options` = "nosniff", 
        `x-frame-options` = "DENY"), class = c("insensitive", 
    "list")), all_headers = list(list(status = 404L, version = "HTTP/1.1", 
        headers = structure(list(server = "Apache-Coyote/1.1", 
            `cache-control` = "no-cache, no-store, max-age=0, must-revalidate", 
            `strict-transport-security` = "max-age=0", date = "Sun, 04 Jun 2023 13:59:40 GMT", 
            `x-application-context` = "application", expires = "0", 
            `x-xss-protection` = "1; mode=block", pragma = "no-cache", 
            `transfer-encoding` = "chunked", `x-content-type-options` = "nosniff", 
            `x-frame-options` = "DENY"), class = c("insensitive", 
        "list")))), cookies = structure(list(domain = logical(0), 
        flag = logical(0), path = logical(0), secure = logical(0), 
        expiration = structure(numeric(0), class = c("POSIXct", 
        "POSIXt")), name = logical(0), value = logical(0)), row.names = integer(0), class = "data.frame"), 
    content = raw(0), date = structure(1685887180, class = c("POSIXct", 
    "POSIXt"), tzone = "GMT"), times = c(redirect = 0, namelookup = 1.9e-05, 
    connect = 0, pretransfer = 6.6e-05, starttransfer = 0.062761, 
    total = 0.062799)), class = "response")
